function EDFSPulseOverlay_AWG_PUMP_BW(B_axis, spc_real, det_frq, det_fld, es_pulses, shape_number, shape_name, User_date, Phase, Descr)
% B_axis axis in mT, spc is EDFS intensity and is real and normalised.
% det_frq in GHz, det_fld in mT
% pulse is an EasySpin pulse structure (or cell array thereof)

%% Set up
% Convert to SI units
det_frq = det_frq*1e9;
det_fld = det_fld*1e-3;
B_axis = B_axis*1e-3;

% Calculate frequency axis
g_Obs = (planck*det_frq)./(bmagn.*B_axis);
f_axis = (bmagn.*det_fld.*g_Obs)./(planck);
offsets = f_axis - det_frq;

% Convert to MHz
f_axis = f_axis./1e6;
offsets = offsets./1e6;

% Make cell array if not already
if iscell(es_pulses)==0
    es_pulses = {es_pulses};
end

% Make sure cell array is the right way around
if size(es_pulses, 1) ~= 1
    for n = 1:size(es_pulses, 1)
        pulse_copy{1, n} = es_pulses{n, 1};
    end
    es_pulses = pulse_copy;
end

%% Plot EDFS on frequency axis
h=figure(101);
hold on;

plot(offsets, spc_real./max(abs(spc_real)))

%% Make inversion profiles for each phase of shaped pulse
for n = 1:size(es_pulses, 2)
    % Make pulse profile
    [es_pulses{1, n}.t, es_pulses{1, n}.IQ] = pulse(es_pulses{1, n});
    tc = es_pulses{1, n}.tp/2; % centre of pulse
    
    % Interpolate values
    %es_pulses{1, i}.tc_I = interp1(es_pulses{1, i}.t,real(es_pulses{1, i}.IQ),es_pulses{1,i}.tp/2);
    %es_pulses{1, i}.tc_Q = interp1(es_pulses{1, i}.t,imag(es_pulses{1, i}.IQ),es_pulses{1,i}.tp/2);
    
    % Fix phase of pulse shape
    %es_pulses{1, i}.tc_phase = angle(complex(es_pulses{1, i}.tc_I,es_pulses{1, i}.tc_Q));
    %es_pulses{1, i}.IQ = exp(-1i.*(es_pulses{1, i}.tc_phase+es_pulses{1, i}.Phase)).*es_pulses{1, i}.IQ;
    
    [es_pulses{1, n}.Offsets, es_pulses{1, n}.M] = exciteprofile(es_pulses{1, n}.t, es_pulses{1, n}.IQ, offsets);

    % Invert and scale
    es_pulses{1, n}.M(3,:) = -es_pulses{1, n}.M(3,:);
    es_pulses{1, n}.M(3,:) = es_pulses{1, n}.M(3,:)-min(es_pulses{1, n}.M(3,:));
    es_pulses{1, n}.M(3,:) = es_pulses{1, n}.M(3,:)./2;
end
% Add to plot
plot(offsets, es_pulses{1, 1}.M(3,:))
%plot(offsets, es_pulses{1, 2}.M(3,:))
%plot(offsets, es_pulses{1, 3}.M(3,:))% change for plotting purposes
xlabel('Frequency Offset (MHz)')
ylabel('Signal Intensity (a.u.)')
%set(gca,'YTick',[])
axis tight
legend('EDFS','Detection')
h=make_plot_nice_overlay_AWG(h);
h.Renderer='opengl';
hold off

for n = 1:size(es_pulses, 2)
%% Plot real and imag part of AWG shaped pump pulse
h=figure(n);
hold on

if max(abs(es_pulses{1, n}.IQ))>=1
    es_pulses{1, n}.IQ = es_pulses{1, n}.IQ./max(abs(es_pulses{1, n}.IQ));
end

plot(es_pulses{1, n}.t,real(es_pulses{1, n}.IQ))
plot(es_pulses{1, n}.t,imag(es_pulses{1, n}.IQ))
yline(0)
xline(tc)
hold off

xlabel('Time (s)')
ylabel('Amplitude (MHz)')
axis([])
legend('real','imag')

h=make_plot_nice_overlay_AWG(h);
h.Renderer='opengl';

% Save for input to spectrometer
save_IQ = [real(es_pulses{1, n}.IQ);imag(es_pulses{1, n}.IQ)];
SH = shape_number(1);
P = Phase(1);
filename = sprintf('Shape%d.shp',SH);
fileID = fopen(filename,'w+');
fprintf(fileID,';Shape%d\n',SH);
fprintf(fileID,';%s',User_date);
fprintf(fileID,'\n;Phase %d',P);
fprintf(fileID,'\n;%s\n',Descr);
fprintf(fileID,'\nbegin shape%d',SH);
fprintf(fileID,' "%s"\n', shape_name);
fprintf(fileID,'%6.3f, %6.3f\n',save_IQ);
fprintf(fileID,'end shape%d',SH);
end