%% EDFS (AWG Shaped) Pulse Overlay File
%  Using easyspins pulse.m function
%  Output: .shp files for Bruker spectrometer
%
%
%  ciaran.rogers@manchester.ac.uk
% =========================================================================
clear all
close all

%% Load EDFS
[B_mT,spc,pars] = eprload('');
B_mT=B_mT/10;

spc_real = real(spc./max(abs(real(spc))));

%% Resonator response
[bx,by] = eprload('');

%% Define pulses 
% Shaped pulse
AWG_pulse_pump.tp = 0.1;
AWG_pulse_pump.n = 1;
AWG_pulse_pump.beta = 1;
AWG_pulse_pump.Frequency = [-300 -100];
AWG_pulse_pump.Type = 'WURST*sech/tanh';
AWG_pulse_pump.nwurst = 5;
AWG_pulse_pump.TimeStep = 0.000625; % us 
AWG_pulse_pump.Phase = 0;
AWG_pulse_pump.mwFreq = 33.93;
AWG_pulse_pump.FrequencyResponse = [bx by];

%% Detection
det_frq = 33.93; % Frequency of detection pulse 
det_fld = 1211.6; % Field position of detection pulse mT

%% Compile inputs
allpulses = {AWG_pulse_pump};

%% .sph file info - 
User_date = 'Ciaran Rogers, 2023';
Descr = 'WURST';
Phase = [0]; % +x +y -x -y
 
% Define shape slot 
shape_number = [208];
shape_name = 'WURST208';
 
% Save variables as shape name
fname = sprintf('%s.mat',shape_name);
save(fname);
%% Run function
clf
EDFSPulseOverlay_AWG_PUMP_BW(B_mT, spc_real, det_frq, det_fld, allpulses, shape_number, shape_name, User_date, Phase, Descr);
